==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/servicenetworking/kotlin/FrontendsInterface.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicenetworking.kotlin

import com.pulumi.azurenative.servicenetworking.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.servicenetworking.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [FrontendsInterface].
 */
@PulumiTagMarker
public class FrontendsInterfaceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: FrontendsInterfaceArgs = FrontendsInterfaceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend FrontendsInterfaceArgsBuilder.() -> Unit) {
        val builder = FrontendsInterfaceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): FrontendsInterface {
        val builtJavaResource =
            com.pulumi.azurenative.servicenetworking.FrontendsInterface(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return FrontendsInterface(builtJavaResource)
    }
}

/**
 * Frontend Subresource of Traffic Controller.
 * Azure REST API version: 2023-05-01-preview. Prior API version in Azure Native 1.x: 2022-10-01-preview.
 * Other available API versions: 2022-10-01-preview, 2023-11-01.
 * ## Example Usage
 * ### Put Frontend
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var frontendsInterface = new AzureNative.ServiceNetworking.FrontendsInterface("frontendsInterface", new()
 *     {
 *         FrontendName = "fe1",
 *         Location = "NorthCentralUS",
 *         ResourceGroupName = "rg1",
 *         TrafficControllerName = "tc1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/servicenetworking/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := servicenetworking.NewFrontendsInterface(ctx, "frontendsInterface", &servicenetworking.FrontendsInterfaceArgs{
 * 			FrontendName:          pulumi.String("fe1"),
 * 			Location:              pulumi.String("NorthCentralUS"),
 * 			ResourceGroupName:     pulumi.String("rg1"),
 * 			TrafficControllerName: pulumi.String("tc1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.servicenetworking.FrontendsInterface;
 * import com.pulumi.azurenative.servicenetworking.FrontendsInterfaceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var frontendsInterface = new FrontendsInterface("frontendsInterface", FrontendsInterfaceArgs.builder()
 *             .frontendName("fe1")
 *             .location("NorthCentralUS")
 *             .resourceGroupName("rg1")
 *             .trafficControllerName("tc1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:servicenetworking:FrontendsInterface fe1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ServiceNetworking/trafficControllers/{trafficControllerName}/frontends/{frontendName}
 * ```
 */
public class FrontendsInterface internal constructor(
    override val javaResource: com.pulumi.azurenative.servicenetworking.FrontendsInterface,
) : KotlinCustomResource(javaResource, FrontendsInterfaceMapper) {
    /**
     * The Fully Qualified Domain Name of the DNS record associated to a Traffic Controller frontend.
     */
    public val fqdn: Output<String>
        get() = javaResource.fqdn().applyValue({ args0 -> args0 })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Provisioning State of Traffic Controller Frontend Resource
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object FrontendsInterfaceMapper : ResourceMapper<FrontendsInterface> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.servicenetworking.FrontendsInterface::class == javaResource::class

    override fun map(javaResource: Resource): FrontendsInterface = FrontendsInterface(
        javaResource as
            com.pulumi.azurenative.servicenetworking.FrontendsInterface,
    )
}

/**
 * @see [FrontendsInterface].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [FrontendsInterface].
 */
public suspend fun frontendsInterface(
    name: String,
    block: suspend FrontendsInterfaceResourceBuilder.() -> Unit,
): FrontendsInterface {
    val builder = FrontendsInterfaceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [FrontendsInterface].
 * @param name The _unique_ name of the resulting resource.
 */
public fun frontendsInterface(name: String): FrontendsInterface {
    val builder = FrontendsInterfaceResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicenetworking/kotlin/FrontendsInterface.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicenetworking.kotlin

import com.pulumi.azurenative.servicenetworking.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.servicenetworking.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [FrontendsInterface].
 */
@PulumiTagMarker
public class FrontendsInterfaceResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: FrontendsInterfaceArgs = FrontendsInterfaceArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend FrontendsInterfaceArgsBuilder.() -> Unit) {
        val builder = FrontendsInterfaceArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): FrontendsInterface {
        val builtJavaResource =
            com.pulumi.azurenative.servicenetworking.FrontendsInterface(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return FrontendsInterface(builtJavaResource)
    }
}

/**
 * Frontend Subresource of Traffic Controller.
 * Azure REST API version: 2023-05-01-preview. Prior API version in Azure Native 1.x: 2022-10-01-preview.
 * Other available API versions: 2022-10-01-preview, 2023-11-01.
 * ## Example Usage
 * ### Put Frontend
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var frontendsInterface = new AzureNative.ServiceNetworking.FrontendsInterface("frontendsInterface", new()
 *     {
 *         FrontendName = "fe1",
 *         Location = "NorthCentralUS",
 *         ResourceGroupName = "rg1",
 *         TrafficControllerName = "tc1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/servicenetworking/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := servicenetworking.NewFrontendsInterface(ctx, "frontendsInterface", &servicenetworking.FrontendsInterfaceArgs{
 * 			FrontendName:          pulumi.String("fe1"),
 * 			Location:              pulumi.String("NorthCentralUS"),
 * 			ResourceGroupName:     pulumi.String("rg1"),
 * 			TrafficControllerName: pulumi.String("tc1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.servicenetworking.FrontendsInterface;
 * import com.pulumi.azurenative.servicenetworking.FrontendsInterfaceArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var frontendsInterface = new FrontendsInterface("frontendsInterface", FrontendsInterfaceArgs.builder()
 *             .frontendName("fe1")
 *             .location("NorthCentralUS")
 *             .resourceGroupName("rg1")
 *             .trafficControllerName("tc1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:servicenetworking:FrontendsInterface fe1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ServiceNetworking/trafficControllers/{trafficControllerName}/frontends/{frontendName}
 * ```
 */
public class FrontendsInterface internal constructor(
    override val javaResource: com.pulumi.azurenative.servicenetworking.FrontendsInterface,
) : KotlinCustomResource(javaResource, FrontendsInterfaceMapper) {
    /**
     * The Fully Qualified Domain Name of the DNS record associated to a Traffic Controller frontend.
     */
    public val fqdn: Output<String>
        get() = javaResource.fqdn().applyValue({ args0 -> args0 })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Provisioning State of Traffic Controller Frontend Resource
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object FrontendsInterfaceMapper : ResourceMapper<FrontendsInterface> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.servicenetworking.FrontendsInterface::class == javaResource::class

    override fun map(javaResource: Resource): FrontendsInterface = FrontendsInterface(
        javaResource as
            com.pulumi.azurenative.servicenetworking.FrontendsInterface,
    )
}

/**
 * @see [FrontendsInterface].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [FrontendsInterface].
 */
public suspend fun frontendsInterface(
    name: String,
    block: suspend FrontendsInterfaceResourceBuilder.() -> Unit,
): FrontendsInterface {
    val builder = FrontendsInterfaceResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [FrontendsInterface].
 * @param name The _unique_ name of the resulting resource.
 */
public fun frontendsInterface(name: String): FrontendsInterface {
    val builder = FrontendsInterfaceResourceBuilder()
    builder.name(name)
    return builder.build()
}
